@@ -45,6 +45,7 @@ from yd_commands.common import (
 )
 from yd_commands.config_keys import *
 from yd_commands.printing import print_error, print_log
+from yd_commands.validate_properties import validate_properties
 from yd_commands.wrapper import CLIENT, CONFIG_COMMON, main_wrapper
 
 # Import the configuration from the TOML file
@@ -69,6 +70,7 @@ def main():
             tasks_data = load_json_file(wr_json_file)
         else:
             tasks_data = load_json_file_with_mustache_substitutions(wr_json_file)
+        validate_properties(tasks_data, "Work Requirement JSON")
         submit_work_requirement(
             directory_to_upload_from=dirname(wr_json_file),
             tasks_data=tasks_data,
@@ -242,6 +244,8 @@ def submit_work_requirement(
         except Exception as e:
             print_error(e)
             cleanup_on_failure(work_requirement)
+            if ARGS_PARSER.stack_trace:
+                raise e
             return
 
     if ARGS_PARSER.follow:
@@ -658,6 +662,8 @@ def create_task(
     # Special processing for Bash tasks. The Bash script is uploaded if not
     # already done, and added to the list of required files.
     if task_type == "bash":
+        if executable is None:
+            raise Exception("No 'executable' specified for 'bash' Task Type")
         if executable not in uploaded_files:
             upload_file(executable, flatten_upload_paths=flatten_upload_paths)
             uploaded_files.append(executable)
@@ -681,6 +687,8 @@ def create_task(
     # Special processing for Docker tasks. Sets up the '-e' environment strings
     # and the DockerHub username and password if specified.
     elif task_type == "docker":
+        if executable is None:
+            raise Exception("No 'executable' specified for 'Docker' Task Type")
         # Set up the environment variables to be sent to the Docker container
         docker_env = task_data.get(
             DOCKER_ENV,
